# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSignedDistanceFunctionPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkPCAShapeSignedDistanceFunctionPython
else:
    import _itkPCAShapeSignedDistanceFunctionPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkTransformBasePython
import itk.itkVariableLengthVectorPython
import itk.itkArray2DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkDiffusionTensor3DPython
import itk.itkShapeSignedDistanceFunctionPython
import itk.itkSpatialFunctionPython
import itk.itkFunctionBasePython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkContinuousIndexPython

def itkPCAShapeSignedDistanceFunctionD2ID2_New():
    return itkPCAShapeSignedDistanceFunctionD2ID2.New()

class itkPCAShapeSignedDistanceFunctionD2ID2(itk.itkShapeSignedDistanceFunctionPython.itkShapeSignedDistanceFunctionD2):
    r"""Proxy of C++ itkPCAShapeSignedDistanceFunctionD2ID2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPCAShapeSignedDistanceFunctionD2ID2_Pointer"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPCAShapeSignedDistanceFunctionD2ID2_Pointer"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_Clone(self)

    def SetNumberOfPrincipalComponents(self, n):
        r"""
        SetNumberOfPrincipalComponents(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_SetNumberOfPrincipalComponents(self, n)

    def GetNumberOfPrincipalComponents(self):
        r"""GetNumberOfPrincipalComponents(self) -> unsigned int"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_GetNumberOfPrincipalComponents(self)

    def SetMeanImage(self, _arg):
        r"""
        SetMeanImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageD2 *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_SetMeanImage(self, _arg)

    def GetModifiableMeanImage(self):
        r"""GetModifiableMeanImage(self) -> itkImageD2"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_GetModifiableMeanImage(self)

    def GetMeanImage(self, *args):
        r"""
        GetMeanImage(self) -> itkImageD2
        GetMeanImage(self) -> itkImageD2
        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_GetMeanImage(self, *args)

    def SetPrincipalComponentImages(self, v):
        r"""
        SetPrincipalComponentImages(self, v)

        Parameters
        ----------
        v: std::vector< itkImageD2_Pointer,std::allocator< itkImageD2_Pointer > >

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_SetPrincipalComponentImages(self, v)

    def SetPrincipalComponentStandardDeviations(self, _arg):
        r"""
        SetPrincipalComponentStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_SetPrincipalComponentStandardDeviations(self, _arg)

    def GetPrincipalComponentStandardDeviations(self):
        r"""GetPrincipalComponentStandardDeviations(self) -> itkOptimizerParametersD"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_GetPrincipalComponentStandardDeviations(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_GetTransform(self, *args)
    __swig_destroy__ = _itkPCAShapeSignedDistanceFunctionPython.delete_itkPCAShapeSignedDistanceFunctionD2ID2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPCAShapeSignedDistanceFunctionD2ID2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPCAShapeSignedDistanceFunctionD2ID2

        Create a new object of the class itkPCAShapeSignedDistanceFunctionD2ID2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPCAShapeSignedDistanceFunctionD2ID2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPCAShapeSignedDistanceFunctionD2ID2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPCAShapeSignedDistanceFunctionD2ID2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPCAShapeSignedDistanceFunctionD2ID2 in _itkPCAShapeSignedDistanceFunctionPython:
_itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2ID2_swigregister(itkPCAShapeSignedDistanceFunctionD2ID2)

def itkPCAShapeSignedDistanceFunctionD2IF2_New():
    return itkPCAShapeSignedDistanceFunctionD2IF2.New()

class itkPCAShapeSignedDistanceFunctionD2IF2(itk.itkShapeSignedDistanceFunctionPython.itkShapeSignedDistanceFunctionD2):
    r"""Proxy of C++ itkPCAShapeSignedDistanceFunctionD2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPCAShapeSignedDistanceFunctionD2IF2_Pointer"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPCAShapeSignedDistanceFunctionD2IF2_Pointer"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_Clone(self)

    def SetNumberOfPrincipalComponents(self, n):
        r"""
        SetNumberOfPrincipalComponents(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_SetNumberOfPrincipalComponents(self, n)

    def GetNumberOfPrincipalComponents(self):
        r"""GetNumberOfPrincipalComponents(self) -> unsigned int"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_GetNumberOfPrincipalComponents(self)

    def SetMeanImage(self, _arg):
        r"""
        SetMeanImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_SetMeanImage(self, _arg)

    def GetModifiableMeanImage(self):
        r"""GetModifiableMeanImage(self) -> itkImageF2"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_GetModifiableMeanImage(self)

    def GetMeanImage(self, *args):
        r"""
        GetMeanImage(self) -> itkImageF2
        GetMeanImage(self) -> itkImageF2
        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_GetMeanImage(self, *args)

    def SetPrincipalComponentImages(self, v):
        r"""
        SetPrincipalComponentImages(self, v)

        Parameters
        ----------
        v: std::vector< itkImageF2_Pointer,std::allocator< itkImageF2_Pointer > >

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_SetPrincipalComponentImages(self, v)

    def SetPrincipalComponentStandardDeviations(self, _arg):
        r"""
        SetPrincipalComponentStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_SetPrincipalComponentStandardDeviations(self, _arg)

    def GetPrincipalComponentStandardDeviations(self):
        r"""GetPrincipalComponentStandardDeviations(self) -> itkOptimizerParametersD"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_GetPrincipalComponentStandardDeviations(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_GetTransform(self, *args)
    __swig_destroy__ = _itkPCAShapeSignedDistanceFunctionPython.delete_itkPCAShapeSignedDistanceFunctionD2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPCAShapeSignedDistanceFunctionD2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPCAShapeSignedDistanceFunctionD2IF2

        Create a new object of the class itkPCAShapeSignedDistanceFunctionD2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPCAShapeSignedDistanceFunctionD2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPCAShapeSignedDistanceFunctionD2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPCAShapeSignedDistanceFunctionD2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPCAShapeSignedDistanceFunctionD2IF2 in _itkPCAShapeSignedDistanceFunctionPython:
_itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD2IF2_swigregister(itkPCAShapeSignedDistanceFunctionD2IF2)

def itkPCAShapeSignedDistanceFunctionD3ID3_New():
    return itkPCAShapeSignedDistanceFunctionD3ID3.New()

class itkPCAShapeSignedDistanceFunctionD3ID3(itk.itkShapeSignedDistanceFunctionPython.itkShapeSignedDistanceFunctionD3):
    r"""Proxy of C++ itkPCAShapeSignedDistanceFunctionD3ID3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPCAShapeSignedDistanceFunctionD3ID3_Pointer"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPCAShapeSignedDistanceFunctionD3ID3_Pointer"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_Clone(self)

    def SetNumberOfPrincipalComponents(self, n):
        r"""
        SetNumberOfPrincipalComponents(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_SetNumberOfPrincipalComponents(self, n)

    def GetNumberOfPrincipalComponents(self):
        r"""GetNumberOfPrincipalComponents(self) -> unsigned int"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_GetNumberOfPrincipalComponents(self)

    def SetMeanImage(self, _arg):
        r"""
        SetMeanImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageD3 *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_SetMeanImage(self, _arg)

    def GetModifiableMeanImage(self):
        r"""GetModifiableMeanImage(self) -> itkImageD3"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_GetModifiableMeanImage(self)

    def GetMeanImage(self, *args):
        r"""
        GetMeanImage(self) -> itkImageD3
        GetMeanImage(self) -> itkImageD3
        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_GetMeanImage(self, *args)

    def SetPrincipalComponentImages(self, v):
        r"""
        SetPrincipalComponentImages(self, v)

        Parameters
        ----------
        v: std::vector< itkImageD3_Pointer,std::allocator< itkImageD3_Pointer > >

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_SetPrincipalComponentImages(self, v)

    def SetPrincipalComponentStandardDeviations(self, _arg):
        r"""
        SetPrincipalComponentStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_SetPrincipalComponentStandardDeviations(self, _arg)

    def GetPrincipalComponentStandardDeviations(self):
        r"""GetPrincipalComponentStandardDeviations(self) -> itkOptimizerParametersD"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_GetPrincipalComponentStandardDeviations(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_GetTransform(self, *args)
    __swig_destroy__ = _itkPCAShapeSignedDistanceFunctionPython.delete_itkPCAShapeSignedDistanceFunctionD3ID3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPCAShapeSignedDistanceFunctionD3ID3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPCAShapeSignedDistanceFunctionD3ID3

        Create a new object of the class itkPCAShapeSignedDistanceFunctionD3ID3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPCAShapeSignedDistanceFunctionD3ID3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPCAShapeSignedDistanceFunctionD3ID3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPCAShapeSignedDistanceFunctionD3ID3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPCAShapeSignedDistanceFunctionD3ID3 in _itkPCAShapeSignedDistanceFunctionPython:
_itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3ID3_swigregister(itkPCAShapeSignedDistanceFunctionD3ID3)

def itkPCAShapeSignedDistanceFunctionD3IF3_New():
    return itkPCAShapeSignedDistanceFunctionD3IF3.New()

class itkPCAShapeSignedDistanceFunctionD3IF3(itk.itkShapeSignedDistanceFunctionPython.itkShapeSignedDistanceFunctionD3):
    r"""Proxy of C++ itkPCAShapeSignedDistanceFunctionD3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPCAShapeSignedDistanceFunctionD3IF3_Pointer"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPCAShapeSignedDistanceFunctionD3IF3_Pointer"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_Clone(self)

    def SetNumberOfPrincipalComponents(self, n):
        r"""
        SetNumberOfPrincipalComponents(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_SetNumberOfPrincipalComponents(self, n)

    def GetNumberOfPrincipalComponents(self):
        r"""GetNumberOfPrincipalComponents(self) -> unsigned int"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_GetNumberOfPrincipalComponents(self)

    def SetMeanImage(self, _arg):
        r"""
        SetMeanImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_SetMeanImage(self, _arg)

    def GetModifiableMeanImage(self):
        r"""GetModifiableMeanImage(self) -> itkImageF3"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_GetModifiableMeanImage(self)

    def GetMeanImage(self, *args):
        r"""
        GetMeanImage(self) -> itkImageF3
        GetMeanImage(self) -> itkImageF3
        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_GetMeanImage(self, *args)

    def SetPrincipalComponentImages(self, v):
        r"""
        SetPrincipalComponentImages(self, v)

        Parameters
        ----------
        v: std::vector< itkImageF3_Pointer,std::allocator< itkImageF3_Pointer > >

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_SetPrincipalComponentImages(self, v)

    def SetPrincipalComponentStandardDeviations(self, _arg):
        r"""
        SetPrincipalComponentStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_SetPrincipalComponentStandardDeviations(self, _arg)

    def GetPrincipalComponentStandardDeviations(self):
        r"""GetPrincipalComponentStandardDeviations(self) -> itkOptimizerParametersD"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_GetPrincipalComponentStandardDeviations(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_GetTransform(self, *args)
    __swig_destroy__ = _itkPCAShapeSignedDistanceFunctionPython.delete_itkPCAShapeSignedDistanceFunctionD3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPCAShapeSignedDistanceFunctionD3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPCAShapeSignedDistanceFunctionD3IF3

        Create a new object of the class itkPCAShapeSignedDistanceFunctionD3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPCAShapeSignedDistanceFunctionD3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPCAShapeSignedDistanceFunctionD3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPCAShapeSignedDistanceFunctionD3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPCAShapeSignedDistanceFunctionD3IF3 in _itkPCAShapeSignedDistanceFunctionPython:
_itkPCAShapeSignedDistanceFunctionPython.itkPCAShapeSignedDistanceFunctionD3IF3_swigregister(itkPCAShapeSignedDistanceFunctionD3IF3)

